# coding: utf-8

"""
TranslationApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class TranslationApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_translation(self, uuid, authorization, **kwargs):
        """
        This is to retrieve a translation that has been queued up (via TranslationRequest uuid)
        Retrieves the translation via UUID

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_translation(uuid, authorization, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str uuid: Uuid (required)
        :param str authorization: Access token required to access the API (required)
        :return: TranslationRequest
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid', 'authorization']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_translation" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'uuid' is set
        if ('uuid' not in params) or (params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `get_translation`")
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params) or (params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_translation`")

        resource_path = '/translation/{uuid}/'.replace('{format}', 'json')
        method = 'GET'

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']

        query_params = {}

        header_params = {}
        if 'authorization' in params:
            header_params['authorization'] = params['authorization']

        form_params = {}
        files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, method,
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=files,
                                            response_type='TranslationRequest',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def update_translation_request(self, uuid, translation_request_creation_payload, authorization, **kwargs):
        """
        
        Update a given translation defined by uuid

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_translation_request(uuid, translation_request_creation_payload, authorization, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str uuid: Uuid (required)
        :param TranslationRequestCreationPayload translation_request_creation_payload: The TranslationRequest Attributes that can be updated (required)
        :param str authorization: The access token required to access the API (required)
        :return: TranslationRequest
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid', 'translation_request_creation_payload', 'authorization']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_translation_request" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'uuid' is set
        if ('uuid' not in params) or (params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `update_translation_request`")
        # verify the required parameter 'translation_request_creation_payload' is set
        if ('translation_request_creation_payload' not in params) or (params['translation_request_creation_payload'] is None):
            raise ValueError("Missing the required parameter `translation_request_creation_payload` when calling `update_translation_request`")
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params) or (params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `update_translation_request`")

        resource_path = '/translation/{uuid}/'.replace('{format}', 'json')
        method = 'POST'

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']

        query_params = {}

        header_params = {}
        if 'authorization' in params:
            header_params['authorization'] = params['authorization']

        form_params = {}
        files = {}

        body_params = None
        if 'translation_request_creation_payload' in params:
            body_params = params['translation_request_creation_payload']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, method,
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=files,
                                            response_type='TranslationRequest',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
